@@ -10,8 +10,9 @@ package Sidef::Types::Glob::Dir {
     sub new {
         my (undef, $dir) = @_;
         if (@_ > 2) {
+            shift(@_);
             state $x = require File::Spec;
-            $dir = File::Spec->catdir(map { "$_" } @_[1 .. $#_]);
+            $dir = File::Spec->catdir(map { "$_" } @_);
         }
         elsif (ref($dir)) {
             return $dir->to_dir;
@@ -133,7 +134,7 @@ package Sidef::Types::Glob::Dir {
 
         my $success = opendir(my $dir_h, "$self");
         my $error   = $!;
-        my $dir_obj = Sidef::Types::Glob::DirHandle->new(dir_h => $dir_h, dir => $self);
+        my $dir_obj = Sidef::Types::Glob::DirHandle->new($dir_h, $self);
 
         if (defined $fh_ref) {
             ${$fh_ref} = $dir_obj;
