@@ -10,7 +10,7 @@ package Sidef::Types::Hash::Hash {
     use overload
       q{bool} => sub { scalar(CORE::keys %{$_[0]}) },
       q{0+}   => sub { scalar(CORE::keys %{$_[0]}) },
-      q{""}   => \&dump;
+      q{""}   => \&_dump;
 
     use Sidef::Types::Bool::Bool;
 
@@ -402,6 +402,42 @@ package Sidef::Types::Hash::Hash {
     }
 
     *to_array = \&to_a;
+    *kv       = \&to_a;
+
+    sub as_tree {
+        my ($self, $root) = @_;
+
+        my %addr;
+
+        my $sub = sub {
+            my ($obj, $root) = @_;
+
+            my $refaddr = Scalar::Util::refaddr($obj);
+
+            exists($addr{$refaddr})
+              && return $addr{$refaddr};
+
+            my @body;
+            $addr{$refaddr} = Sidef::Types::Array::Pair->new($root, \@body);
+
+            foreach my $k (sort { (CORE::length($a) <=> CORE::length($b)) || ($a cmp $b) } CORE::keys %$obj) {
+                my $v = $obj->{$k};
+                if (ref($v) eq __PACKAGE__) {
+                    push @body, $v->as_tree(Sidef::Types::String::String->new($k));
+                }
+                else {
+                    push @body,
+                      Sidef::Types::Array::Pair->new(Sidef::Types::String::String->new($k), Sidef::Types::Array::Array->new);
+                }
+            }
+
+            bless \@body, 'Sidef::Types::Array::Array';
+            $addr{$refaddr};
+        };
+
+        local *Sidef::Types::Hash::Hash::as_tree = $sub;
+        $sub->($_[0], $root);
+    }
 
     sub pairs {
         my ($self, @keys) = @_;
@@ -449,7 +485,7 @@ package Sidef::Types::Hash::Hash {
         map { (Sidef::Types::String::String->new($_), $self->{$_}) } CORE::keys %$self;
     }
 
-    sub dump {
+    sub _dump {
         my %addr;    # keeps track of dumped objects
 
         my $sub = sub {
@@ -465,20 +501,24 @@ package Sidef::Types::Hash::Hash {
             # Sort the keys case insensitively
             my @keys = CORE::sort { (lc($a) cmp lc($b)) || ($a cmp $b) } CORE::keys(%$obj);
 
-            my $str = Sidef::Types::String::String->new("Hash(#`($refaddr)...)");
-            $addr{$refaddr} = $str;
+            $addr{$refaddr} = "Hash(#`($refaddr)...)";
 
-            $$str = (
+            my ($s, $val);
+
+            my $str = (
                 "Hash(" . (
                     @keys
                     ? (
                        (@keys > 1 ? "\n" : '') . join(
                            ",\n",
                            map {
-                               my $val = $obj->{$_};
-                               (@keys > 1 ? (' ' x $Sidef::SPACES) : '')
+                                   (@keys > 1 ? (' ' x $Sidef::SPACES) : '')
                                  . "${Sidef::Types::String::String->new($_)->dump} => "
-                                 . (defined(UNIVERSAL::can($val, 'dump')) ? $val->dump : defined($val) ? $val : 'nil')
+                                 . (
+                                      (ref($val = $obj->{$_}) && ($s = UNIVERSAL::can($val, 'dump'))) ? $s->($val)
+                                    : defined($val) ? $val
+                                    :                 'nil'
+                                   )
                              } @keys
                          )
                          . (@keys > 1 ? ("\n" . (' ' x ($Sidef::SPACES - $Sidef::SPACES_INCR))) : '')
@@ -496,6 +536,10 @@ package Sidef::Types::Hash::Hash {
         $sub->($_[0]);
     }
 
+    sub dump {
+        Sidef::Types::String::String->new($_[0]->_dump);
+    }
+
     {
         no strict 'refs';
 
